summaryrefslogtreecommitdiffstats
path: root/kde.py
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-11-16 13:42:16 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-11-16 13:42:16 -0600
commite91a07ec04736a4dbb004d71a31ea610b1141775 (patch)
tree4c3a7386f49b17fdcd1df3c6669499c44008c742 /kde.py
parentb53f796aecd0115fbf7f3794599b92ee02b95035 (diff)
downloadkstreamripper-e91a07ec04736a4dbb004d71a31ea610b1141775.tar.gz
kstreamripper-e91a07ec04736a4dbb004d71a31ea610b1141775.zip
Additional renaming of kde to tde
Diffstat (limited to 'kde.py')
-rw-r--r--kde.py12
1 files changed, 6 insertions, 6 deletions
diff --git a/kde.py b/kde.py
index b4bcf3b..2eb2e3d 100644
--- a/kde.py
+++ b/kde.py
@@ -35,7 +35,7 @@ def detect_kde(env):
libdir = env['ARGS'].get('libdir', None)
libsuffix = env['ARGS'].get('libsuffix', '')
kdeincludes = env['ARGS'].get('kdeincludes', None)
- kdelibs = env['ARGS'].get('kdelibs', None)
+ tdelibs = env['ARGS'].get('tdelibs', None)
qtincludes = env['ARGS'].get('qtincludes', None)
qtlibs = env['ARGS'].get('qtlibs', None)
@@ -50,7 +50,7 @@ def detect_kde(env):
else:
print RED+"kde-config was NOT found in your PATH"+NORMAL
print "Make sure kde is installed properly"
- print "(missing package kdebase-devel?)"
+ print "(missing package tdebase-devel?)"
env.Exit(1)
env['KDEDIR'] = os.popen('kde-config -prefix').read().strip()
@@ -209,9 +209,9 @@ def detect_kde(env):
## kde libs and includes
env['KDEINCLUDEPATH']=kdeincludes
- if not kdelibs:
- kdelibs=os.popen('kde-config --expandvars --install lib').read().strip()
- env['KDELIBPATH']=kdelibs
+ if not tdelibs:
+ tdelibs=os.popen('kde-config --expandvars --install lib').read().strip()
+ env['KDELIBPATH']=tdelibs
## qt libs and includes
env['QTINCLUDEPATH']=qtincludes
@@ -233,7 +233,7 @@ def generate(env):
"""+BOLD+"""* libsuffix """+NORMAL+""": suffix of libraries on amd64, ie: 64, 32
"""+BOLD+"""* kdeincludes"""+NORMAL+""": path to the kde includes (/usr/include/kde on debian, ...)
"""+BOLD+"""* qtincludes """+NORMAL+""": same punishment, for qt includes (/usr/include/qt on debian, ...)
"""+BOLD+"""* kdelibs """+NORMAL+""": path to the kde libs, for linking the programs
"""+BOLD+"""* qtlibs """+NORMAL+""": same punishment, for qt libraries
ie: """+BOLD+"""scons configure libdir=/usr/local/lib qtincludes=/usr/include/qt
"""+NORMAL)
@@ -233,7 +233,7 @@ def generate(env):
"""+BOLD+"""* kdeincludes"""+NORMAL+""": path to the kde includes (/usr/include/kde on debian, ...)
"""+BOLD+"""* qtincludes """+NORMAL+""": same punishment, for qt includes (/usr/include/qt on debian, ...)
-"""+BOLD+"""* kdelibs """+NORMAL+""": path to the kde libs, for linking the programs
+"""+BOLD+"""* tdelibs """+NORMAL+""": path to the kde libs, for linking the programs
"""+BOLD+"""* qtlibs """+NORMAL+""": same punishment, for qt libraries
ie: """+BOLD+"""scons configure libdir=/usr/local/lib qtincludes=/usr/include/qt